@@ -1,3 +1,4 @@
+use bytes::buf::Buf;
 use bytes::Bytes;
 
 use crate::common::StatementCache;
@@ -8,7 +9,6 @@ use crate::mysql::protocol::connect::{
 };
 use crate::mysql::protocol::Capabilities;
 use crate::mysql::{MySqlConnectOptions, MySqlConnection, MySqlSslMode};
-use bytes::buf::BufExt as _;
 
 impl MySqlConnection {
     pub(crate) async fn establish(options: &MySqlConnectOptions) -> Result<Self, Error> {
